@@ -5,30 +5,26 @@ use cargo_c::install::cinstall;
 
 use cargo::util::command_prelude::flag;
 use cargo::util::command_prelude::ArgMatchesExt;
-use cargo::CliResult;
-use cargo::Config;
+use cargo::{CliResult, GlobalContext};
 
 use clap::*;
 
 fn main() -> CliResult {
-    let mut config = Config::default()?;
+    let mut config = GlobalContext::default()?;
 
     let cli_build = subcommand_build("build", "Build the crate C-API");
     let cli_install = subcommand_install("install", "Install the crate C-API");
     let cli_test = subcommand_test("test");
 
-    let mut app = clap::command!()
-        .dont_collapse_args_in_usage(true)
-        .allow_external_subcommands(true)
-        .subcommand(
-            Command::new("capi")
-                .allow_external_subcommands(true)
-                .about("Build or install the crate C-API")
-                .arg(flag("version", "Print version info and exit").short('V'))
-                .subcommand(cli_build)
-                .subcommand(cli_install)
-                .subcommand(cli_test),
-        );
+    let mut app = main_cli().subcommand(
+        Command::new("capi")
+            .allow_external_subcommands(true)
+            .about("Build or install the crate C-API")
+            .arg(flag("version", "Print version info and exit").short('V'))
+            .subcommand(cli_build)
+            .subcommand(cli_install)
+            .subcommand(cli_test),
+    );
 
     let args = app.clone().get_matches();
 
@@ -60,7 +56,7 @@ fn main() -> CliResult {
         return Ok(());
     }
 
-    config_configure(&mut config, subcommand_args)?;
+    global_context_configure(&mut config, subcommand_args)?;
 
     let mut ws = subcommand_args.workspace(&config)?;
 
@@ -69,7 +65,7 @@ fn main() -> CliResult {
     if cmd == "install" {
         cinstall(&ws, &packages)?;
     } else if cmd == "test" {
-        ctest(&ws, &config, subcommand_args, &packages, compile_opts)?;
+        ctest(&ws, subcommand_args, &packages, compile_opts)?;
     }
 
     Ok(())
