@@ -1,20 +1,16 @@
 use cargo::util::command_prelude::ArgMatchesExt;
 use cargo::CliResult;
-use cargo::Config;
+use cargo::GlobalContext;
 
 use cargo_c::build::*;
-use cargo_c::cli::run_cargo_fallback;
-use cargo_c::cli::subcommand_build;
+use cargo_c::cli::{main_cli, run_cargo_fallback, subcommand_build};
 use cargo_c::config::*;
 
 fn main() -> CliResult {
-    let mut config = Config::default()?;
+    let mut config = GlobalContext::default()?;
 
     let subcommand = subcommand_build("cbuild", "Build the crate C-API");
-    let mut app = clap::command!()
-        .dont_collapse_args_in_usage(true)
-        .allow_external_subcommands(true)
-        .subcommand(subcommand);
+    let mut app = main_cli().subcommand(subcommand);
 
     let args = app.clone().get_matches();
 
@@ -35,7 +31,7 @@ fn main() -> CliResult {
         return Ok(());
     }
 
-    config_configure(&mut config, subcommand_args)?;
+    global_context_configure(&mut config, subcommand_args)?;
 
     let mut ws = subcommand_args.workspace(&config)?;
 
